.. IMTreatment documentation master file, created by
   sphinx-quickstart on Tue Sep 26 14:40:08 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../README.rst

.. toctree::
    :maxdepth: 5
    :hidden:

    doc
    api


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
